macro_rules! get_ref {
($self:expr, $table:ident, $key:expr) => { ... };
}Expand description
Same as get! but returns a reference into the tables instead of cloning
macro_rules! get_ref {
($self:expr, $table:ident, $key:expr) => { ... };
}Same as get! but returns a reference into the tables instead of cloning